# OctoBot-Launcher [1.0.0](https://github.com/Drakkar-Software/OctoBot-Launcher/tree/master/CHANGELOG.md) [![Build Status](https://api.travis-ci.org/Drakkar-Software/OctoBot-Launcher.svg?branch=master)](https://travis-ci.org/Drakkar-Software/OctoBot-Launcher) 

A launcher for your [OctoBot](https://github.com/Drakkar-Software/OctoBot) ! 

## Install
With [Python 3.7](https://www.python.org/downloads/) : 
``` {.sourceCode .bash}
$ pip3 install OctoBot-Launcher
```

## Usage
Start OctoBot launcher with : 
``` {.sourceCode .bash}
$ octobot-launcher
```
